pub struct EnvironmentType<T>(/* private fields */);Expand description
Wrapper around PhantomData to prevent it being filtered by scale-info.
scale-info filters out PhantomData fields because usually we are only interested
in sized types. However, when trying to communicate types as opposed to values
we want to have those zero sized types be included.